import { createEditorInstance, editor } from '@kevisual/codemirror/dist/editor.json';
import { useEffect, useRef, useLayoutEffect, useState, useCallback } from 'react';
import { useLocation, useNavigate } from 'react-router';
import { useCodeEditorStore, ParseData } from './store';
import { useToCodeEditor } from './hooks/use-to-code-editor';
export { useToCodeEditor };
import { Button, message } from 'antd';
export const App = () => {
  const ref = useRef<HTMLDivElement>(null);
  const editorRef = useRef<typeof editor>(null);
  const location = useLocation();
  const store = useCodeEditorStore();
  const [mounted, setMounted] = useState(false);
  useEffect(() => {
    initEditor();
    const state = location.state as ParseData;
    if (state && state.data) {
      store.init(state);
    }
    setMounted(true);
    return () => {
      setMounted(false);
    };
  }, []);
  useLayoutEffect(() => {
    if (!mounted) return;
    if (editorRef.current) {
      setNewValue(store.code);
    } else {
      setNewValue('');
    }
  }, [store.code, mounted]);
  const initEditor = () => {
    const _editor = createEditorInstance(ref.current!);
    editorRef.current = _editor;
  };
  const setNewValue = (value: string) => {
    const editor = editorRef.current;
    if (editor) {
      editor.dispatch({
        changes: [{ from: 0, to: editor.state.doc.length, insert: value }],
      });
    }
  };
  const getValue = () => {
    const editor = editorRef.current;
    if (editor) {
      return editor.state.doc.toString();
    }
    return '';
  };
  const onSave = useCallback(async () => {
    const value = getValue();
    // store.onUpdate(value);
    if (store.dataType === 'object') {
      try {
        JSON.parse(value);
      } catch (error) {
        console.error(error);
        message.error('JSON format error');
        return;
      }
    }
    store.onUpdate(value);
  }, [store.dataType]);
  return (
    <div className='w-full h-full bg-gray-400'>
      <div className='px-2 bg-white mb-4'>Code Editor</div>
      <Button onClick={onSave}>Save</Button>
      <div className='w-full p-4 rounded-md bg-white' style={{ height: 'calc(100% - 130px)' }}>
        <div className='w-full h-full' ref={ref}></div>
      </div>
    </div>
  );
};
