import { useEditStore } from '../store';
import { Button, Input, message, Modal, Table } from 'antd';
import { useEffect, useState } from 'react';
import { useShallow } from 'zustand/react/shallow';
import { Form } from 'antd';
import copy from 'copy-to-clipboard';
import { useNavigate } from 'react-router';
import { useToCodeEditor } from '@/pages/code-editor';

const FormModal = () => {
  const [form] = Form.useForm();
  const editStore = useEditStore(
    useShallow((state) => {
      return {
        showEdit: state.showEditModal,
        setShowEdit: state.setShowEditModal,
        formData: state.formData,
        updateData: state.updateData,
      };
    }),
  );
  useEffect(() => {
    const open = editStore.showEdit;
    if (open) {
      form.setFieldsValue(editStore.formData || {});
    } else {
      form.resetFields();
    }
  }, [editStore.showEdit]);
  const onFinish = async (values: any) => {
    editStore.updateData(values);
  };
  const onClose = () => {
    editStore.setShowEdit(false);
    form.resetFields();
  };
  const isEdit = editStore.formData.id;
  return (
    <Modal title={isEdit ? 'Edit' : 'Add'} open={editStore.showEdit} onClose={onClose} destroyOnClose footer={false} width={800} onCancel={onClose}>
      <Form
        form={form}
        onFinish={onFinish}
        labelCol={{
          span: 4,
        }}
        wrapperCol={{
          span: 20,
        }}>
        <Form.Item name='id' hidden>
          <Input />
        </Form.Item>
        <Form.Item name='title' label='title'>
          <Input />
        </Form.Item>
        {/* <Form.Item name='code' label='code'>
          <TextArea value={containerStore.formData.code} />
        </Form.Item> */}
        <Form.Item label=' ' colon={false}>
          <Button type='primary' htmlType='submit'>
            Submit
          </Button>
          <Button className='ml-2' htmlType='reset' onClick={onClose}>
            Cancel
          </Button>
        </Form.Item>
      </Form>
    </Modal>
  );
};
export const List = () => {
  const navicate = useNavigate();
  const toCodeEditor = useToCodeEditor();
  const editStore = useEditStore(
    useShallow((state) => {
      return {
        setFormData: state.setFormData,
        setShowEdit: state.setShowEditModal,
        list: state.list,
        deleteData: state.deleteData,
        getList: state.getList,
        loading: state.loading,
      };
    }),
  );
  useEffect(() => {
    editStore.getList();
  }, []);

  const columns = [
    {
      title: 'ID',
      dataIndex: 'id',
      render: (text: string) => {
        return (
          <div
            className='w-40 truncate cursor-pointer'
            title={text}
            onClick={() => {
              copy(text);
              message.success('copy success');
            }}>
            {text}
          </div>
        );
      },
    },
    {
      title: 'Title',
      dataIndex: 'title',
    },

    {
      title: 'Operation',
      dataIndex: 'operation',
      render: (text: string, record: any) => {
        return (
          <div className='flex gap-2'>
            <Button
              type='primary'
              onClick={() => {
                editStore.setFormData(record);
                editStore.setShowEdit(true);
              }}>
              Edit
            </Button>
            <Button
              onClick={() => {
                navicate('/panel/flow/' + record.id);
              }}>
              Flow
            </Button>
            <Button
              onClick={() => {
                navicate('/panel/deck/' + record.id);
              }}>
              Deck
            </Button>
            <Button
              onClick={() => {
                toCodeEditor.toPagePage(record);
              }}>
              Source Data Editor
            </Button>
            <Button
              danger
              onClick={() => {
                editStore.deleteData(record.id);
              }}>
              Delete
            </Button>
          </div>
        );
      },
    },
  ];
  return (
    <div className='w-full h-full flex flex-col'>
      <div className='mb-2 w-full p-2 bg-white rounded-lg'>
        <Button
          className='w-20 '
          type='primary'
          onClick={() => {
            editStore.setFormData({});
            editStore.setShowEdit(true);
          }}>
          Add
        </Button>
      </div>
      <div className='flex-grow overflow-scroll'>
        <Table
          pagination={false}
          scroll={{
            y: 600,
          }}
          loading={editStore.loading}
          dataSource={editStore.list}
          rowKey='id'
          columns={columns}
        />
      </div>
      <div className='h-2'></div>
      <FormModal />
    </div>
  );
};
