import { useCallback, useEffect, useState } from 'react';
import {
  ReactFlow,
  MiniMap,
  Controls,
  Background,
  useNodesState,
  useEdgesState,
  addEdge,
  ReactFlowProvider,
  useStore,
  NodeTypes,
  useReactFlow,
  useStoreApi,
  Panel,
} from '@xyflow/react';
import '@xyflow/react/dist/style.css';
import { useShallow } from 'zustand/react/shallow';
import { Container, useAddNode, ContainerMenusList, useMenuFlow } from '@abearxiong/flows';
import { useMenuEmitter, ContainerMenusKeys } from '@abearxiong/flows';
import { nanoid } from 'nanoid';
import { Button } from 'antd';
import { usePanelStore } from '../store';
// router: Router
const nodeTypes = {
  container: Container,
};

export const Flow = () => {
  return (
    <ReactFlowProvider>
      <ReactFlowApp />
    </ReactFlowProvider>
  );
};
const ReactFlowApp = () => {
  const [nodes, setNodes, onNodesChange] = useNodesState([]);
  const [edges, setEdges, onEdgesChange] = useEdgesState<any>([]);

  const onConnect = useCallback((params) => setEdges((eds) => addEdge(params, eds)), [setEdges]);
  const panelStore = usePanelStore(
    useShallow((state) => {
      return {
        data: state.data,
        saveNodesEdges: state.saveNodesEdges,
      };
    }),
  );
  useEffect(() => {
    if (panelStore.data?.id) {
      const { data } = panelStore.data || {};
      const nodes = data.nodes || [];
      const edges = data.edges || [];
      setNodes(nodes);
      setEdges(edges);
    } else {
      setNodes([]);
      setEdges([]);
    }
  }, [panelStore.data]);
  const { menuCom, onContextMenu, onClose } = useMenuFlow(
    (item, cacheData) => {
      emit({
        menu: item,
        data: cacheData,
      });
    },
    {
      menusList: ContainerMenusList,
    },
  );

  const { emit } = useMenuEmitter<ContainerMenusKeys>({
    preview: ({ menu, data }) => {
      console.log('preview', data);
      if (data?.data?.cid) {
        window.open(`/container/preview/${data.data.cid}`, '_blank');
      }
    },
  });
  const { onNeedAdd, onAdd, onMouseMove, adding } = useAddNode();
  const onSave = useCallback(() => {
    panelStore.saveNodesEdges({
      nodes,
      edges,
    });
  }, [nodes, edges]);

  return (
    <ReactFlow
      nodes={nodes}
      edges={edges}
      onNodesChange={onNodesChange}
      onEdgesChange={onEdgesChange}
      onConnect={onConnect}
      onChange={(e) => {
        console.log('change', e);
      }}
      onChangeCapture={(e) => {
        console.log('change capture', e);
      }}
      onNodeDragStop={(e) => {
        console.log('drag stop', e);
      }}
      nodeTypes={nodeTypes}
      onMove={(e, viewport) => {
        // console.log('move', e, viewport)
      }}
      onContextMenu={(e) => {
        e.preventDefault();
      }}
      onPaneClick={(e) => {
        if (adding) {
          onAdd();
        }
      }}
      onNodeContextMenu={(e, node) => {
        console.log('context menu', e, node);
        onContextMenu(e as any, node);
      }}
      onMouseMove={(e) => onMouseMove(e)}
      onClick={(e) => {
        onClose();
      }}>
      <MiniMap />
      <Controls />
      {/* <Background gap={[14, 14]} size={2} color='#E4E5E7' /> */}
      <Background color='#000' />
      <Panel>{menuCom}</Panel>
      <Panel>
        <div className='flex gap-2'>
          <Button
            type='primary'
            onClick={(e) => {
              onNeedAdd({ id: nanoid(6), data: { label: '容器' }, type: 'container' }, e);
            }}>
            测试添加按钮
          </Button>
          <Button
            onClick={() => {
              onSave();
            }}>
            保存
          </Button>
        </div>
      </Panel>
    </ReactFlow>
  );
};

export default Flow;
